from dataclasses import dataclass


@dataclass
class AdminPurgeComment:
    """https://join-lemmy.org/api/interfaces/AdminPurgeComment.html"""

    admin_person_id: int = None
    id: int = None
    post_id: int = None
    reason: str = None
    when_: str = None


@dataclass
class AdminPurgeCommunity:
    """https://join-lemmy.org/api/interfaces/AdminPurgeCommunity.html"""

    admin_person_id: int = None
    id: int = None
    reason: str = None
    when_: str = None


@dataclass
class AdminPurgePerson:
    """https://join-lemmy.org/api/interfaces/AdminPurgePerson.html"""

    admin_person_id: int = None
    id: int = None
    reason: str = None
    when_: str = None


@dataclass
class AdminPurgePost:
    """https://join-lemmy.org/api/interfaces/AdminPurgePost.html"""

    admin_person_id: int = None
    community_id: int = None
    id: int = None
    reason: str = None
    when_: str = None


@dataclass
class CaptchaResponse:
    """https://join-lemmy.org/api/interfaces/CaptchaResponse.html"""

    png: str = None
    uuid: str = None
    wav: str = None


@dataclass
class Comment:
    """https://join-lemmy.org/api/interfaces/Comment.html"""

    ap_id: str = None
    content: str = None
    creator_id: int = None
    deleted: bool = None
    distinguished: bool = None
    id: int = None
    language_id: int = None
    local: bool = None
    path: str = None
    post_id: int = None
    published: str = None
    removed: bool = None
    updated: str = None


@dataclass
class CommentAggregates:
    """https://join-lemmy.org/api/interfaces/CommentAggregates.html"""

    child_count: int = None
    comment_id: int = None
    downvotes: int = None
    hot_rank: int = None
    id: int = None
    published: str = None
    score: int = None
    upvotes: int = None


@dataclass
class CommentReply:
    """https://join-lemmy.org/api/interfaces/CommentReply.html"""

    comment_id: int = None
    id: int = None
    published: str = None
    read: bool = None
    recipient_id: int = None


@dataclass
class CommentReport:
    """https://join-lemmy.org/api/interfaces/CommentReport.html"""

    comment_id: int = None
    creator_id: int = None
    id: int = None
    original_comment_text: str = None
    published: str = None
    reason: str = None
    resolved: bool = None
    resolver_id: int = None
    updated: str = None


@dataclass
class Community:
    """https://join-lemmy.org/api/interfaces/Community.html"""

    description: str = None
    icon: str = None
    id: int = None
    name: str = None
    title: str = None
    removed: bool = None
    published: str = None
    deleted: bool = None
    nsfw: bool = None
    actor_id: str = None
    local: bool = None
    hidden: bool = None
    posting_restricted_to_mods: bool = None
    instance_id: int = None
    updated: str = None
    banner: bool = None


@dataclass
class CommunityAggregates:
    """https://join-lemmy.org/api/interfaces/CommunityAggregates.html"""

    id: int = None
    community_id: int = None
    subscribers: int = None
    posts: int = None
    comments: int = None
    published: str = None
    users_active_day: int = None
    users_active_week: int = None
    users_active_month: int = None
    users_active_half_year: int = None
    hot_rank: int = None


@dataclass
class CustomEmoji:
    """https://join-lemmy.org/api/interfaces/CustomEmoji.html"""

    alt_text: str = None
    category: str = None
    id: int = None
    image_url: str = None
    local_site_id: int = None
    published: str = None
    shortcode: str = None
    updated: str = None


@dataclass
class CustomEmojiKeyword:
    """https://join-lemmy.org/api/interfaces/CustomEmojiKeyword.html"""

    custom_emoji_id: int = None
    id: int = None
    keyword: str = None


@dataclass
class ImageFile:
    """https://join-lemmy.org/api/interfaces/ImageFile.html"""

    delete_token: str = None
    file: str = None


@dataclass
class Instance:
    """https://join-lemmy.org/api/interfaces/Instance.html"""

    domain: str = None
    id: int = None
    published: str = None
    software: str = None
    updated: str = None
    version: str = None


@dataclass
class Language:
    """https://join-lemmy.org/api/interfaces/Language.html"""

    code: str = None
    id: int = None
    name: str = None


@dataclass
class LocalSite:
    """https://join-lemmy.org/api/interfaces/LocalSite.html"""

    actor_name_max_length: int = None
    application_email_admins: bool = None
    application_question: str = None
    captcha_difficulty: str = None
    captcha_enabled: bool = None
    community_creation_admin_only: bool = None
    default_post_listing_type: str = None
    default_theme: str = None
    enable_downvotes: bool = None
    enable_nsfw: bool = None
    federation_enabled: bool = None
    hide_modlog_mod_names: bool = None
    id: int = None
    legal_information: str = None
    private_instance: bool = None
    published: str = None
    registration_mode: str = None
    reports_email_admins: bool = None
    require_email_verification: bool = None
    site_id: int = None
    site_setup: bool = None
    slur_filter_regex: str = None
    updated: str = None


@dataclass
class LocalSiteRateLimit:
    """https://join-lemmy.org/api/interfaces/LocalSiteRateLimit.html"""

    comment: int = None
    comment_per_second: int = None
    id: int = None
    image: int = None
    image_per_second: int = None
    local_site_id: int = None
    message: int = None
    message_per_second: int = None
    post: int = None
    post_per_second: int = None
    published: str = None
    register: int = None
    register_per_second: int = None
    search: int = None
    search_per_second: int = None
    updated: str = None


@dataclass
class LocalUser:
    """https://join-lemmy.org/api/interfaces/LocalUser.html"""

    accepted_application: bool = None
    default_listing_type: str = None
    default_sort_type: str = None
    email: str = None
    email_verified: bool = None
    id: int = None
    interface_language: str = None
    open_links_in_new_tab: bool = None
    person_id: int = None
    send_notifications_to_email: bool = None
    show_avatars: bool = None
    show_bot_accounts: bool = None
    show_new_post_notifs: bool = None
    show_nsfw: bool = None
    show_read_posts: bool = None
    show_scores: bool = None
    theme: str = None
    totp_2fa_url: str = None
    validator_time: str = None


@dataclass
class ModAdd:
    """https://join-lemmy.org/api/interfaces/ModAdd.html"""

    id: int = None
    mod_person_id: int = None
    other_person_id: int = None
    removed: bool = None
    when_: str = None


@dataclass
class ModAddCommunity:
    """https://join-lemmy.org/api/interfaces/ModAddCommunity.html"""

    community_id: int = None
    id: int = None
    mod_person_id: int = None
    other_person_id: int = None
    removed: bool = None
    when_: str = None


@dataclass
class ModBan:
    """https://join-lemmy.org/api/interfaces/ModBan.html"""

    banned: bool = None
    expires: str = None
    id: int = None
    mod_person_id: int = None
    other_person_id: int = None
    reason: str = None
    when_: str = None


@dataclass
class ModBanFromCommunity:
    """https://join-lemmy.org/api/interfaces/ModBanFromCommunity.html"""

    banned: bool = None
    community_id: int = None
    expires: str = None
    id: int = None
    mod_person_id: int = None
    other_person_id: int = None
    reason: str = None
    when_: str = None


@dataclass
class ModFeaturePost:
    """https://join-lemmy.org/api/interfaces/ModFeaturePost.html"""

    featured: bool = None
    id: int = None
    is_featured_community: bool = None
    mod_person_id: int = None
    post_id: int = None
    when_: str = None


@dataclass
class ModHideCommunity:
    """https://join-lemmy.org/api/interfaces/ModHideCommunity.html"""

    community_id: int = None
    hidden: bool = None
    id: int = None
    mod_person_id: int = None
    reason: str = None
    when_: str = None


@dataclass
class ModLockPost:
    """https://join-lemmy.org/api/interfaces/ModLockPost.html"""

    id: int = None
    locked: bool = None
    mod_person_id: int = None
    post_id: int = None
    when_: str = None


@dataclass
class ModRemoveComment:
    """https://join-lemmy.org/api/interfaces/ModRemoveComment.html"""

    comment_id: int = None
    id: int = None
    mod_person_id: int = None
    removed: bool = None
    reason: str = None
    when_: str = None


@dataclass
class ModRemoveCommunity:
    """https://join-lemmy.org/api/interfaces/ModRemoveCommunity.html"""

    community_id: int = None
    expires: str = None
    id: int = None
    mod_person_id: int = None
    removed: bool = None
    reason: str = None
    when_: str = None


@dataclass
class ModRemovePost:
    """https://join-lemmy.org/api/interfaces/ModRemovePost.html"""

    id: int = None
    mod_person_id: int = None
    post_id: int = None
    removed: bool = None
    reason: str = None
    when_: str = None


@dataclass
class ModTransferCommunity:
    """https://join-lemmy.org/api/interfaces/ModTransferCommunity.html"""

    community_id: int = None
    id: int = None
    mod_person_id: int = None
    other_person_id: int = None
    when_: str = None


@dataclass
class Person:
    """https://join-lemmy.org/api/interfaces/Person.html"""

    actor_id: str = None
    admin: bool = None
    avatar: str = None
    ban_expires: str = None
    banned: bool = None
    banner: str = None
    bio: str = None
    bot_account: bool = None
    deleted: bool = None
    display_name: str = None
    id: int = None
    inbox_url: str = None
    instance_id: int = None
    local: bool = None
    matrix_user_id: str = None
    name: str = None
    published: str = None
    updated: str = None


@dataclass
class PersonAggregates:
    """https://join-lemmy.org/api/interfaces/PersonAggregates.html"""

    comment_count: int = None
    comment_score: int = None
    id: int = None
    person_id: int = None
    post_count: int = None
    post_score: int = None


@dataclass
class PersonMention:
    """https://join-lemmy.org/api/interfaces/PersonMention.html"""

    comment_id: int = None
    id: int = None
    published: str = None
    read: bool = None
    recipient_id: int = None


@dataclass
class Post:
    """https://join-lemmy.org/api/interfaces/Post.html"""

    ap_id: str = None
    body: str = None
    community_id: int = None
    creator_id: int = None
    deleted: bool = None
    embed_description: str = None
    embed_title: str = None
    embed_video_url: str = None
    featured_community: bool = None
    featured_local: bool = None
    id: int = None
    language_id: int = None
    local: bool = None
    locked: bool = None
    name: str = None
    nsfw: bool = None
    published: str = None
    removed: bool = None
    thumbnail_url: str = None
    updated: str = None
    url: str = None


@dataclass
class PostAggregates:
    """https://join-lemmy.org/api/interfaces/PostAggregates.html"""

    comments: int = None
    downvotes: int = None
    featured_community: bool = None
    featured_local: bool = None
    hot_rank: int = None
    hot_rank_active: int = None
    id: int = None
    newest_comment_time: str = None
    newest_comment_time_necro: str = None
    post_id: int = None
    published: str = None
    score: int = None
    upvotes: int = None


@dataclass
class PostReport:
    """https://join-lemmy.org/api/interfaces/PostReport.html"""

    creator_id: int = None
    id: int = None
    original_post_body: str = None
    original_post_name: str = None
    original_post_url: str = None
    post_id: int = None
    published: str = None
    reason: str = None
    resolved: bool = None
    resolver_id: int = None
    updated: str = None


@dataclass
class PrivateMessage:
    """https://join-lemmy.org/api/interfaces/PrivateMessage.html"""

    ap_id: str = None
    content: str = None
    creator_id: int = None
    deleted: bool = None
    id: int = None
    local: bool = None
    published: str = None
    read: bool = None
    recipient_id: int = None
    updated: str = None


@dataclass
class PrivateMessageReport:
    """https://join-lemmy.org/api/interfaces/PrivateMessageReport.html"""

    creator_id: int = None
    id: int = None
    original_pm_text: str = None
    private_message_id: int = None
    published: str = None
    reason: str = None
    resolved: bool = None
    resolver_id: int = None
    updated: str = None


@dataclass
class RegistrationApplication:
    """https://join-lemmy.org/api/interfaces/RegistrationApplication.html"""

    admin_id: int = None
    answer: str = None
    deny_reason: str = None
    id: int = None
    local_user_id: int = None
    published: str = None


@dataclass
class Site:
    """https://join-lemmy.org/api/interfaces/Site.html"""

    actor_id: str = None
    banner: str = None
    description: str = None
    icon: str = None
    id: int = None
    inbox_url: str = None
    instance_id: int = None
    last_refreshed_at: str = None
    name: str = None
    private_key: str = None
    public_key: str = None
    published: str = None
    sidebar: str = None
    updated: str = None


@dataclass
class SiteAggregates:
    """https://join-lemmy.org/api/interfaces/SiteAggregates.html"""

    comments: int = None
    communities: int = None
    id: int = None
    posts: int = None
    site_id: int = None
    users: int = None
    users_active_day: int = None
    users_active_half_year: int = None
    users_active_month: int = None
    users_active_week: int = None


@dataclass
class SiteMetadata:
    """https://join-lemmy.org/api/interfaces/SiteMetadata.html"""

    description: str = None
    embed_video_url: str = None
    image: str = None
    title: str = None


@dataclass
class Tagline:
    """https://join-lemmy.org/api/interfaces/Tagline.html"""

    content: str = None
    id: int = None
    local_site_id: int = None
    published: str = None
    updated: str = None



from .objects import AdminPurgeComment, AdminPurgeCommunity,\
    AdminPurgePerson, AdminPurgePost, Comment, CommentAggregates,\
    CommentReply, CommentReport, Community, CommunityAggregates, CustomEmoji,\
    CustomEmojiKeyword, Instance, LocalSite, LocalSiteRateLimit, LocalUser,\
    ModAdd, ModAddCommunity, ModBan, ModBanFromCommunity, ModFeaturePost,\
    ModHideCommunity, ModLockPost, ModRemoveComment, ModRemoveCommunity,\
    ModRemovePost, ModTransferCommunity, Person, PersonAggregates,\
    PersonMention, Post, PostAggregates, PostReport, PrivateMessage,\
    PrivateMessageReport, RegistrationApplication, Site, SiteAggregates


class ViewObject(object):
    """ ViewObject: parent object to all view-related objects """

    def __init__(self, view: dict) -> None:

        self._view = view
        self.parse()

    def parse(self) -> None:

        return


class AdminPurgeCommentView(ViewObject):
    """https://join-lemmy.org/api/interfaces/AdminPurgeCommentView.html"""

    def parse(self) -> None:

        if "admin" in self._view.keys():
            self.admin = Person(**self._view["admin"])
        else:
            self.admin = None
        self.admin_purge_comment = AdminPurgeComment(
            **self._view["admin_purge_comment"]
        )
        self.post = Post(**self._view["post"])


class AdminPurgeCommunityView(ViewObject):
    """https://join-lemmy.org/api/interfaces/AdminPurgeCommunityView.html"""

    def parse(self) -> None:

        if "admin" in self._view.keys():
            self.admin = Person(**self._view["admin"])
        else:
            self.admin = None
        self.admin_purge_community = AdminPurgeCommunity(
            **self._view["admin_purge_community"]
        )


class AdminPurgePersonView(ViewObject):
    """https://join-lemmy.org/api/interfaces/AdminPurgePersonView.html"""

    def parse(self) -> None:

        if "admin" in self._view.keys():
            self.admin = Person(**self._view["admin"])
        else:
            self.admin = None
        self.admin_purge_person = AdminPurgePerson(
            **self._view["admin_purge_person"]
        )


class AdminPurgePostView(ViewObject):
    """https://join-lemmy.org/api/interfaces/AdminPurgePostView.html"""

    def parse(self) -> None:

        if "admin" in self._view.keys():
            self.admin = Person(**self._view["admin"])
        self.admin_purge_post = AdminPurgePost(
            **self._view["admin_purge_post"]
        )
        self.community = Community(**self._view["community"])


class CommentReplyView(ViewObject):
    """https://join-lemmy.org/api/interfaces/CommentReplyView.html"""

    def parse(self) -> None:

        self.comment = Comment(**self._view["comment"])
        self.comment_reply = CommentReply(**self._view["comment_reply"])
        self.community = Community(**self._view["community"])
        self.counts = CommentAggregates(**self._view["counts"])
        self.creator = Person(**self._view["creator"])
        self.creator_banned_from_community = self._view[
            "creator_banned_from_community"
        ]
        self.creator_blocked = self._view["creator_blocked"]
        if "my_vote" in self._view.keys():
            self.my_vote = self._view["my_vote"]
        else:
            self.my_vote = None
        self.post = Post(**self._view["post"])
        self.recipient = Person(**self._view["recipient"])
        self.saved = self._view["saved"]
        self.subscribed = self._view["subscribed"]


class CommentReportView(ViewObject):
    """https://join-lemmy.org/api/interfaces/CommentReportView.html"""

    def parse(self) -> None:

        self.comment = Comment(**self._view["comment"])
        self.comment_creator = Person(**self._view["comment_creator"])
        self.comment_report = CommentReport(**self._view["comment_report"])
        self.community = Community(**self._view["community"])
        self.counts = CommentAggregates(**self._view["counts"])
        self.creator = Person(**self._view["creator"])
        self.creator_banned_from_community = self._view[
            "creator_banned_from_community"
        ]
        if "my_vote" in self._view.keys():
            self.my_vote = self._view["my_vote"]
        else:
            self.my_vote = None
        self.post = Post(**self._view["post"])
        if "resolver" in self._view.keys():
            self.resolver = Person(**self._view["resolver"])
        else:
            self.resolver = None


class CommentView(ViewObject):
    """https://join-lemmy.org/api/interfaces/CommentView.html"""

    def parse(self) -> None:

        self.comment = Comment(**self._view["comment"])
        self.community = Community(**self._view["community"])
        self.counts = CommentAggregates(**self._view["counts"])
        self.creator = Person(**self._view["creator"])
        self.creator_banned_from_community = self._view[
            "creator_banned_from_community"
        ]
        self.creator_blocked = self._view["creator_blocked"]
        if "my_vote" in self._view.keys():
            self.my_vote = self._view["my_vote"]
        else:
            self.my_vote = None
        self.post = Post(**self._view["post"])
        self.saved = self._view["saved"]
        self.subscribed = self._view["subscribed"]


class CommunityModeratorView(ViewObject):
    """https://join-lemmy.org/api/interfaces/CommunityModeratorView.html"""

    def parse(self) -> None:

        self.community = Community(**self._view["community"])
        self.moderator = Person(**self._view["moderator"])


class CommunityView(ViewObject):
    """https://join-lemmy.org/api/interfaces/CommunityView.html"""

    def parse(self) -> None:

        self.blocked = self._view["blocked"]
        self.community = Community(**self._view["community"])
        self.counts = CommunityAggregates(**self._view["counts"])
        self.subscribed = self._view["subscribed"]


class CustomEmojiView(ViewObject):
    """https://join-lemmy.org/api/interfaces/CustomEmojiView.html"""

    def parse(self) -> None:

        self.custom_emoji = CustomEmoji(**self._view["custom_emoji"])
        self.keywords = CustomEmojiKeyword(**self._view["keywords"])


class FederatedInstances(ViewObject):
    """https://join-lemmy.org/api/interfaces/FederatedInstances.html"""

    def parse(self) -> None:

        self.allowed = [Instance(**i) for i in self._view["allowed"]]
        self.blocked = [Instance(**i) for i in self._view["blocked"]]
        self.linked = [Instance(**i) for i in self._view["linked"]]


class ModAddCommunityView(ViewObject):
    """https://join-lemmy.org/api/interfaces/ModAddCommunityView.html"""

    def parse(self) -> None:

        self.community = Community(**self._view["community"])
        self.mod_add_community = ModAddCommunity(
            **self._view["mod_add_community"]
        )
        self.modded_person = Person(**self._view["modded_person"])
        if "moderator" in self._view.keys():
            self.moderator = Person(**self._view["moderator"])
        else:
            self.moderator = None


class ModAddView(ViewObject):
    """https://join-lemmy.org/api/interfaces/ModAddView.html"""

    def parse(self) -> None:

        self.mod_add = ModAdd(**self._view["mod_add"])
        self.modded_person = Person(**self._view["modded_person"])
        if "moderator" in self._view.keys():
            self.moderator = Person(**self._view["moderator"])
        else:
            self.moderator = None


class ModBanFromCommunityView(ViewObject):
    """https://join-lemmy.org/api/interfaces/ModBanFromCommunityView.html"""

    def parse(self) -> None:

        self.banned_person = Person(**self._view["banned_person"])
        self.community = Community(**self._view["community"])
        self.mod_ban_from_community = ModBanFromCommunity(
            **self._view["mod_ban_from_community"]
        )
        if "moderator" in self._view.keys():
            self.moderator = Person(**self._view["moderator"])
        else:
            self.moderator = None


class ModBanView(ViewObject):
    """https://join-lemmy.org/api/interfaces/ModBanView.html"""

    def parse(self) -> None:

        self.banned_person = Person(**self._view["banned_person"])
        self.mod_ban = ModBan(**self._view["mod_ban"])
        if "moderator" in self._view.keys():
            self.moderator = Person(**self._view["moderator"])
        else:
            self.moderator = None


class ModFeaturePostView(ViewObject):
    """https://join-lemmy.org/api/interfaces/ModFeaturePostView.html"""

    def parse(self) -> None:

        self.community = Community(**self._view["community"])
        self.mod_feature_post = ModFeaturePost(
            **self._view["mod_feature_post"]
        )
        if "moderator" in self._view.keys():
            self.moderator = Person(**self._view["moderator"])
        else:
            self.moderator = None
        self.post = Post(**self._view["post"])


class ModHideCommunityView(ViewObject):
    """https://join-lemmy.org/api/interfaces/ModHideCommunityView.html"""

    def parse(self) -> None:

        if "admin" in self._view.keys():
            self.admin = Person(**self._view["admin"])
        else:
            self.admin = None
        self.community = Community(**self._view["community"])
        self.mod_hide_community = ModHideCommunity(
            **self._view["mod_hide_community"]
        )


class ModLockPostView(ViewObject):
    """https://join-lemmy.org/api/interfaces/ModLockPostView.html"""

    def parse(self) -> None:

        self.community = Community(**self._view["community"])
        self.mod_lock_post = ModLockPost(**self._view["mod_lock_post"])
        if "moderator" in self._view.keys():
            self.moderator = Person(**self._view["moderator"])
        else:
            self.moderator = None
        self.post = Post(**self._view["post"])


class ModRemoveCommentView(ViewObject):
    """https://join-lemmy.org/api/interfaces/ModRemoveCommentView.html"""

    def parse(self) -> None:

        self.comment = Comment(**self._view["comment"])
        self.commenter = Person(**self._view["commenter"])
        self.community = Community(**self._view["community"])
        self.mod_remove_comment = ModRemoveComment(
            **self._view["mod_remove_comment"]
        )
        if "moderator" in self._view.keys():
            self.moderator = Person(**self._view["moderator"])
        else:
            self.moderator = None
        self.post = Post(**self._view["post"])


class ModRemoveCommunityView(ViewObject):
    """https://join-lemmy.org/api/interfaces/ModRemoveCommunityView.html"""

    def parse(self) -> None:

        self.community = Community(**self._view["community"])
        self.mod_remove_community = ModRemoveCommunity(
            **self._view["mod_remove_community"]
        )
        if "moderator" in self._view.keys():
            self.moderator = Person(**self._view["moderator"])
        else:
            self.moderator = None


class ModRemovePostView(ViewObject):
    """https://join-lemmy.org/api/interfaces/ModRemovePostView.html"""

    def parse(self) -> None:

        self.community = Community(**self._view["community"])
        self.mod_remove_post = ModRemovePost(**self._view["mod_remove_post"])
        if "moderator" in self._view.keys():
            self.moderator = Person(**self._view["moderator"])
        else:
            self.moderator = None
        self.post = Post(**self._view["post"])


class ModTransferCommunityView(ViewObject):
    """https://join-lemmy.org/api/interfaces/ModTransferCommunityView.html"""

    def parse(self) -> None:

        self.community = Community(**self._view["community"])
        self.mod_transfer_community = ModTransferCommunity(
            **self._view["mod_transfer_community"]
        )
        self.modded_person = Person(**self._view["modded_person"])
        if "moderator" in self._view.keys():
            self.moderator = Person(**self._view["moderator"])
        else:
            self.moderator = None


class PersonMentionView(ViewObject):
    """https://join-lemmy.org/api/interfaces/PersonMentionView.html"""

    def parse(self) -> None:

        self.comment = Comment(**self._view["comment"])
        self.community = Community(**self._view["community"])
        self.counts = CommentAggregates(**self._view["counts"])
        self.creator = Person(**self._view["creator"])
        self.creator_banned_from_community = self._view[
            "creator_banned_from_community"
        ]
        self.creator_blocked = self._view["creator_blocked"]
        if "my_vote" in self._view.keys():
            self.my_vote = self._view["my_vote"]
        else:
            self.my_vote = None
        self.person_mention = PersonMention(**self._view["person_mention"])
        self.post = Post(**self._view["post"])
        self.recipient = Person(**self._view["recipient"])
        self.saved = self._view["saved"]
        self.subscribed = self._view["subscribed"]


class PersonView(ViewObject):
    """https://join-lemmy.org/api/interfaces/PersonView.html"""

    def parse(self) -> None:

        self.counts = PersonAggregates(**self._view["counts"])
        self.person = Person(**self._view["person"])


class PostReportView(ViewObject):
    """https://join-lemmy.org/api/interfaces/PostReportView.html"""

    def parse(self) -> None:

        self.community = Community(**self._view["community"])
        self.counts = PostAggregates(**self._view["counts"])
        self.creator = Person(**self._view["creator"])
        self.creator_banned_from_community = self._view[
            "creator_banned_from_community"
        ]
        if "my_vote" in self._view.keys():
            self.my_vote = self._view["my_vote"]
        else:
            self.my_vote = None
        self.post = Post(**self._view["post"])
        self.post_creator = Person(**self._view["post_creator"])
        self.post_report = PostReport(**self._view["post_report"])
        if "resolver" in self._view.keys():
            self.resolver = Person(**self._view["resolver"])
        else:
            self.resolver = None


class PostView(ViewObject):
    """https://join-lemmy.org/api/interfaces/PostView.html"""

    def parse(self) -> None:

        self.community = Community(**self._view["community"])
        self.counts = PostAggregates(**self._view["counts"])
        self.creator = Person(**self._view["creator"])
        self.creator_banned_from_community = self._view[
            "creator_banned_from_community"
        ]
        self.creator_blocked = self._view["creator_blocked"]
        if "my_vote" in self._view.keys():
            self.my_vote = self._view["my_vote"]
        else:
            self.my_vote = None
        self.post = Post(**self._view["post"])
        self.read = self._view["read"]
        self.saved = self._view["saved"]
        self.subscribed = self._view["subscribed"]
        self.unread_comments = self._view["unread_comments"]


class PrivateMessageReportView(ViewObject):
    """https://join-lemmy.org/api/interfaces/PrivateMessageReportView.html"""

    def parse(self) -> None:

        self.creator = Person(**self._view["creator"])
        self.private_message = PrivateMessage(**self._view["private_message"])
        self.private_message_creator = Person(
            **self._view["private_message_creator"]
        )
        self.private_message_report = PrivateMessageReport(
            **self._view["private_message_report"]
        )
        if "resolver" in self._view.keys():
            self.resolver = Person(**self._view["resolver"])
        else:
            self.resolver = None


class PrivateMessageView(ViewObject):
    """https://join-lemmy.org/api/interfaces/PrivateMessageView.html"""

    def parse(self) -> None:

        self.creator = Person(**self._view["creator"])
        self.private_message = PrivateMessage(**self._view["private_message"])
        self.recipient = Person(**self._view["recipient"])


class RegistrationApplicationView(ViewObject):
    """https://join-lemmy.org/api/interfaces/RegistrationApplicationView.html"""

    def parse(self) -> None:

        if "admin" in self._view.keys():
            self.admin = Person(**self._view["admin"])
        else:
            self.admin = None
        self.creator = Person(**self._view["creator"])
        self.creator_local_user = LocalUser(**self._view["creator_local_user"])
        self.registration_application = RegistrationApplication(
            **self._view["registration_application"]
        )


class SiteView(ViewObject):
    """https://join-lemmy.org/api/interfaces/SiteView.html"""

    def parse(self) -> None:

        self.counts = SiteAggregates(**self._view["counts"])
        self.local_site = LocalSite(**self._view["local_site"])
        self.local_site_rate_limit = LocalSiteRateLimit(
            **self._view["local_site_rate_limit"]
        )
        self.site = Site(**self._view["site"])
